#!/usr/bin/zsh
# -*- shell-script -*-

# Test _Dbg_is_alias
test_validate_is_alias()
{
    _Dbg_is_alias 
    assertFalse 'No function given; is_alias should report false' $? 

    typeset al
    unalias testing_is_alias 2>/dev/null 
    _Dbg_is_alias testing_is_alias
    assertFalse 'testing_is_alias should not be defined' $? 

    alias testing_is_alias=true
    _Dbg_is_alias testing_is_alias
    assertTrue 'test_is_alias should now be defined' "$?"
    unalias testing_is_alias
}

# Test _Dbg_is_function
test_validate_is_function()
{
    _Dbg_is_function 
    assertFalse 'No function given; is_function should report false' $? 

    typeset fn
    fn=$(declare -f function_test >/dev/null 2>&1)
    [[ -n "$fn" ]] && unset -f function_test
    _Dbg_is_function function_test
    assertFalse 'function_test should not be defined' $? 

    typeset -i function_test=1
    _Dbg_is_function function_test
    assertFalse 'test_function should still not be defined' "$?"

    function_test() { :; }
    _Dbg_is_function function_test
    assertTrue 'test_function should now be defined' "$?"

    function another_function_test { :; }
    _Dbg_is_function another_function_test "$?"

    _function_test() { :; }
    _Dbg_is_function _function_test
    rc=$?
    assertFalse 'fn _function_test is system fn; is_function should report false' $rc

    _Dbg_is_function _function_test 1 
    assertTrue 'fn _function_test is system fn which we want; should report true' $? 
}

# Test _Dbg_is_int
test_validate_is_integer()
{
    _Dbg_is_int
    assertFalse 'No integer given; is_int should report false' $? 

    for arg in a a1 '-+-' ; do
	_Dbg_is_int $arg
	assertFalse "$arg is not an integer; is_int should report false" $? 
	_Dbg_is_signed_int $arg
	assertFalse "$arg is not a signed integer; is_int should report false" $? 
    done

    for arg in 0 123 9999999 ; do
	_Dbg_is_int $arg
	assertTrue "$arg is an integer; is_int should report true" $? 
	_Dbg_is_signed_int $arg
	assertTrue "$arg is a signed integer; is_int should report true" $? 
    done

    for arg in +0 -123 ; do
	_Dbg_is_signed_int $arg
	assertTrue "$arg is not a signed integer; is_int should report true" $? 
	_Dbg_is_int $arg
	assertFalse "$arg is not an integer; is_int should report true" $? 
    done

}

# Make sure /src/external-vcs/github/rocky/zshdb has a trailing slash
if [ '/src/external-vcs/github/rocky/zshdb' = '' ] ; then
  echo "Something is wrong abs_top_srcdir is not set."
 exit 1
fi
abs_top_srcdir=/src/external-vcs/github/rocky/zshdb
abs_top_srcdir=${abs_top_srcdir%%/}/
. ${abs_top_srcdir}test/unit/helper.sh
. $abs_top_srcdir/dbg-pre.sh
. $abs_top_srcdir/lib/validate.sh
. $abs_top_srcdir/lib/frame.sh
. $abs_top_srcdir/lib/journal.sh
. $abs_top_srcdir/lib/save-restore.sh
set -- # reset $# so shunit2 doesn't get confused.

SHUNIT_PARENT=$0

[[ 0 == ${#funcfiletrace[@]} ]] && . ${shunit_file}
